@@ -21,6 +21,7 @@ class TaipowerElectricMeter:
         self._json : dict = electric_meter_json
         self._ami : Optional[Dict[str, model.TaipowerAMI]] = None
         self._ami_bill : Optional[model.TaipowerAMIBill] = None
+        self._ami_unbilled : Optional[model.TaipowerAMIUnbilled] = None
         self._bill_records : Optional[Dict[str, model.TaipowerBillRecord]] = None
     
     def __repr__(self) -> str:
@@ -88,6 +89,14 @@ class TaipowerElectricMeter:
     def ami_bill(self, x : model.TaipowerAMIBill):
         self._ami_bill = x
     
+    @property
+    def ami_unbilled(self) -> Optional[model.TaipowerAMIUnbilled]:
+        return self._ami_unbilled
+    
+    @ami_unbilled.setter
+    def ami_unbilled(self, x : model.TaipowerAMIUnbilled):
+        self._ami_unbilled = x
+    
     @property
     def bill_records(self) -> Optional[Dict[str, model.TaipowerBillRecord]]:
         return self._bill_records
@@ -143,6 +152,17 @@ class TaipowerElectricMeter:
         """
 
         return self._json["electricNumber"]
+
+    @property
+    def number_verified(self) -> bool:
+        """Whether or not the electric number is verified.
+
+        Returns
+        -------
+        bool
+            Return True if the number is verified.
+        """
+        return True if self._json["verifiedLevel"] not in ["0", "-1"] else False
     
     @property
     def type(self) -> str:
@@ -198,7 +218,7 @@ class TaipowerAPI:
     ) -> None:
 
         if ami_period not in ["quater", "hour", "daily", "monthly"]:
-            raise ValueError("ami_period accepts either `quater`, `hour`, `daily`, `monthly`.")
+            raise ValueError("ami_period accepts either `quater`, `hour`, `daily` or `monthly`.")
 
         self.account : str = account
         self.password : str = password
@@ -223,9 +243,9 @@ class TaipowerAPI:
         return self._meters
     
     def _check_before_publish(self) -> None:
-        # Reauthenticate 5 mins before TaipowerTokens expiration.
+        # Reauthenticate 2 hours (7200 seconds), which is regarded as logged out, before TaipowerTokens expiration.
         current_time = time.time()
-        if self._taipower_tokens.expiration - current_time <= 300:
+        if self._taipower_tokens.expiration - current_time <= 7200:
             self.reauth()
     
     def login(self) -> None:
@@ -278,7 +298,7 @@ class TaipowerAPI:
             taipower_tokens=self._taipower_tokens,
             print_response=self.print_response,
         )
-        conn_status, self._aws_tokens = conn.login(use_refresh_token=use_refresh_token)
+        conn_status, self._taipower_tokens = conn.login(use_refresh_token=use_refresh_token)
         if conn_status != "OK":
             raise RuntimeError(f"An error occurred when reauthenticating with Taipower API: {conn_status}")
     
@@ -398,6 +418,61 @@ class TaipowerAPI:
         else:
             raise RuntimeError(f"An error occurred when retrieving AMI bill: {conn_status}")
 
+    def get_ami_unbilled(self, electric_number : str) -> model.TaipowerAMIUnbilled:
+        """Get AMI unbilled.
+
+        Parameters
+        ----------
+        electric_number : str
+            Electric number.
+
+        Returns
+        -------
+        model.TaipowerAMIUnbilled
+            AMI unbilled.
+
+        Raises
+        ------
+        RuntimeError
+            If an error occurs, RuntimeError will be raised.
+        """
+
+        return asyncio.run(self.async_get_ami_unbilled(electric_number))
+
+    async def async_get_ami_unbilled(self, electric_number : str, client : httpx.AsyncClient = None) -> model.TaipowerAMIUnbilled:
+        """Asynchronously get AMI unbilled.
+
+        Parameters
+        ----------
+        electric_number : str
+            Electric number.
+        client : httpx.AsyncClient, optional
+            AsyncClient for requests, by default None
+
+        Returns
+        -------
+        model.TaipowerAMIUnbilled
+            AMI unbilled.
+
+        Raises
+        ------
+        RuntimeError
+            If an error occurs, RuntimeError will be raised.
+        """
+
+        conn = connection.GetAMIUnbilled(
+            account=self.account,
+            password=self.password,
+            taipower_tokens=self._taipower_tokens,
+            print_response=self.print_response,
+        )
+        conn_status, conn_json = await conn.async_get_data(electric_number, client=client)
+
+        if conn_status == "OK":
+            return model.TaipowerAMIUnbilled(conn_json["data"])
+        else:
+            raise RuntimeError(f"An error occurred when retrieving AMI unbilled: {conn_status}")
+
     def get_bill_records(self, electric_number : int) -> Dict[str, model.TaipowerBillRecord]:
         """Get bill records.
 
@@ -457,6 +532,7 @@ class TaipowerAPI:
         electric_number : str = None,
         refresh_ami : bool = True,
         refresh_ami_bill : bool = True,
+        refresh_ami_unbilled : bool = True,
         refresh_bill_records : bool = True,
     ):
         """Refresh status from Taipower API.
@@ -469,6 +545,8 @@ class TaipowerAPI:
             Whether or not to refresh AMI, by default True
         refresh_ami_bill : bool, optional
             Whether or not to refresh AMI bill, by default True
+        refresh_ami_unbilled : bool, optional
+            Whether or not to refresh AMI unbilled, by default True
         refresh_bill_records : bool, optional
             Whether or not to refresh bill records, by default True
 
@@ -485,27 +563,30 @@ class TaipowerAPI:
 
         client = httpx.AsyncClient()
         async_functions = []
-        return_storages = []
+        return_storage = []
         errors = []
 
         for number, meter in self._meters.items():
             if electric_number and number != electric_number:
                 continue
-            if refresh_ami:
+            if refresh_ami and meter.number_verified:
                 async_functions.append(self.async_get_ami(number, client=client))
-                return_storages.append((meter, "ami"))
+                return_storage.append((meter, "ami"))
             if refresh_ami_bill:
                 async_functions.append(self.async_get_ami_bill(number, client=client))
-                return_storages.append((meter, "ami_bill"))
+                return_storage.append((meter, "ami_bill"))
+            if refresh_ami_unbilled:
+                async_functions.append(self.async_get_ami_unbilled(number, client=client))
+                return_storage.append((meter, "ami_unbilled"))
             if refresh_bill_records:
                 async_functions.append(self.async_get_bill_records(number, client=client))
-                return_storages.append((meter, "bill_records"))
+                return_storage.append((meter, "bill_records"))
 
         list(
             map(
                 lambda x, y: setattr(y[0], y[1], x) if not isinstance(x, Exception) else errors.append(x),
                 asyncio.run(run(async_functions)),
-                return_storages
+                return_storage
             )
         )
 
